eprllib.ActionFunctions.ActionFunctions — eprllib: use EnergyPlus as an environment for DRL control

Skip to main content
`Ctrl`+`K`

# eprllib.ActionFunctions.ActionFunctions

## Action Function Base Class

This module contain the base class to create action transformer functions and define the action space dimention in the environment.

Action transformer functions are used to adapt the action given for the neural network, normally an integral for discrete spaces and a float for continuos spaces as Box. The actions must be adecuated to values required for the actuators in EnergyPlus. Each agent has the capacity to control one actuator.

ActionFunction must be define in the EnvConfig definition to create the environment and is called in the EnergyPlusEnvironment.EnergyPlusEnv_v0 class and used in the EnergyPlusRunner.EnergyPlusRunner class to transform the dict of agent actions to actuator values.

Classes

`ActionFunction`([action_fn_config]) | Base class to create action transformer functions.